package de.juplo.facebook.errors;


import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_EMPTY;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;



/**
 * This class represents an error message from the Graph-API
 *
 * @see <a href="https://developers.facebook.com/docs/graph-api/using-graph-api/v2.5#errors">Graph-API Documentation</a>
 * @author Kai Moritz
 */
@JsonRootName("error")
@JsonPropertyOrder({
  "message",
  "type",
  "code",
  "error_subcode",
  "error_user_title",
  "error_user_msg",
  "fbtrace_id"
  })
@JsonIgnoreProperties(ignoreUnknown = true)
public class FacebookErrorMessage
{
  @JsonProperty("message")
  @JsonInclude(NON_EMPTY)
  String message;
  @JsonProperty("type")
  @JsonInclude(NON_EMPTY)
  String type;
  @JsonProperty("code")
  @JsonInclude(NON_EMPTY)
  Integer code;
  @JsonProperty("error_subcode")
  @JsonInclude(NON_EMPTY)
  Integer subCode;
  @JsonProperty("error_user_title")
  @JsonInclude(NON_EMPTY)
  String userTitle;
  @JsonProperty("error_user_msg")
  @JsonInclude(NON_EMPTY)
  String userMessage;
  @JsonProperty("fbtrace_id")
  @JsonInclude(NON_EMPTY)
  String traceId;
  @JsonProperty("is_transient")
  @JsonInclude(NON_EMPTY)
  Boolean isTransient;


  FacebookErrorMessage() {}

  FacebookErrorMessage(Exception e)
  {
    message = e.toString();
  }
}
