package de.juplo.facebook.errors;


import org.springframework.http.HttpStatus;
import org.springframework.web.reactive.function.client.ClientRequest;
import org.springframework.web.reactive.function.client.ClientResponse;
import org.springframework.web.reactive.function.client.ExchangeFilterFunction;
import org.springframework.web.reactive.function.client.ExchangeFunction;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import reactor.core.publisher.Mono;


/**
 * An {@link ExchangeFilterFunction}
 * @author Kai Moritz
 */
public class GraphApiExchangeFilterFunction implements ExchangeFilterFunction
{
  @Override
  public Mono<ClientResponse> filter(ClientRequest request, ExchangeFunction next)
  {
    return
        next
            .exchange(request)
            .flatMap(response ->
            {
              return
                  HttpStatus.Series.CLIENT_ERROR.equals(response.statusCode().series())
                      ? response
                          .bodyToMono(String.class)
                          .map(errorBody -> GraphApiException.create(
                              response.statusCode(),
                              response.headers().asHttpHeaders(),
                              errorBody.getBytes()))
                          .map(e ->
                              e.getClass().equals(ErrorResponseParsingErrorException.class)
                                  ? WebClientResponseException
                                      .create(
                                          e.getStatus().value(),
                                          e.getStatus().getReasonPhrase(),
                                          e.getHeaders(),
                                          null,
                                          null)
                                  : e)
                          .flatMap(e -> Mono.error(e))
                      : Mono.just(response);
            });
  }
}
